// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
#![cfg_attr(docsrs, feature(doc_cfg))]
#![cfg_attr(docsrs, doc(cfg(feature = "ns-dpv")))]
//! This module provides terms for `dpv` vocabulary
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**||
//! |**Prefix**|dpv|
//! |**Namespace base IRI**|<http://www.w3.org/ns/dpv#>|
//! |**Description**||
//! |**Is defined by**|<https://dpvcg.github.io/dpv/dpv.jsonld>|
//!

use crate::namespace;

namespace!(
    "http://www.w3.org/ns/dpv#",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `Academic Research`: 
    AcademicResearch, "AcademicResearch",
    /// `Accent`: 
    Accent, "Accent",
    /// `Access Control`: 
    AccessControl, "AccessControl",
    /// `Access Control Method`: 
    AccessControlMethod, "AccessControlMethod",
    /// `Account Identifier`: 
    AccountIdentifier, "AccountIdentifier",
    /// `Acquantaince`: 
    Acquantaince, "Acquantaince",
    /// `Acquire`: 
    Acquire, "Acquire",
    /// `Adapt`: 
    Adapt, "Adapt",
    /// `Advertising`: Advertising is a subset of Marketing. Advertising by itself does not indicate 'personalisation' i.e. personalised ads.
    Advertising, "Advertising",
    /// `Age`: 
    Age, "Age",
    /// `Align`: 
    Align, "Align",
    /// `Alter`: 
    Alter, "Alter",
    /// `Analyse`: 
    Analyse, "Analyse",
    /// `Anonymise`: 
    Anonymise, "Anonymise",
    /// `Anonymization`: 
    Anonymization, "Anonymization",
    /// `Apartment Owned`: 
    ApartmentOwned, "ApartmentOwned",
    /// `Association`: 
    Association, "Association",
    /// `Attitude`: 
    Attitude, "Attitude",
    /// `Authenticating`: 
    Authenticating, "Authenticating",
    /// `Authentication History`: 
    AuthenticationHistory, "AuthenticationHistory",
    /// `Authentication Protocols`: 
    AuthenticationProtocols, "AuthenticationProtocols",
    /// `Authorisation Procedure`: non-technical authorisation procedures: How is it described on an organisational level, who gets access to the data
    AuthorisationProcedure, "AuthorisationProcedure",
    /// `Authority`: 
    Authority, "Authority",
    /// `Automated Decision Making`: 
    AutomatedDecisionMaking, "AutomatedDecisionMaking",
    /// `Bank Account`: 
    BankAccount, "BankAccount",
    /// `Behavioral`: 
    Behavioral, "Behavioral",
    /// `Biometric`: 
    Biometric, "Biometric",
    /// `Blood Type`: 
    BloodType, "BloodType",
    /// `Browser Fingerprint`: 
    BrowserFingerprint, "BrowserFingerprint",
    /// `Browsing Behavior`: 
    BrowsingBehavior, "BrowsingBehavior",
    /// `BrowsingBehaviour`: 
    BrowsingBehaviour, "BrowsingBehaviour",
    /// `Browsing Referral`: 
    BrowsingReferral, "BrowsingReferral",
    /// `Call Log`: 
    CallLog, "CallLog",
    /// `Car Owned`: 
    CarOwned, "CarOwned",
    /// `Certification`: 
    Certification, "Certification",
    /// `Certification and Seal`: 
    CertificationSeal, "CertificationSeal",
    /// `Character`: 
    Character, "Character",
    /// `Child`: The legality of age defining a child varies by jurisdiction. In addition, 'child' is distinct from a 'minor'. For example, the legal age drinking alcohol can be 21, which makes a person of age 20 a 'minor' in this context. In other cases, 'minor' and 'child' are used interchangeably to refer to a person below some legally defined age.
    Child, "Child",
    /// `Code of Conduct`: 
    CodeOfConduct, "CodeOfConduct",
    /// `Collect`: 
    Collect, "Collect",
    /// `Combine`: 
    Combine, "Combine",
    /// `Commercial Interest`: 
    CommercialInterest, "CommercialInterest",
    /// `Commercial Research`: 
    CommercialResearch, "CommercialResearch",
    /// `Communication`: 
    Communication, "Communication",
    /// `Communication for Customer Care`: 
    CommunicationForCustomerCare, "CommunicationForCustomerCare",
    /// `Communications Metadata`: 
    CommunicationsMetadata, "CommunicationsMetadata",
    /// `Connection`: 
    Connection, "Connection",
    /// `Consent`: 
    Consent, "Consent",
    /// `Consult`: 
    Consult, "Consult",
    /// `Consultation`: 
    Consultation, "Consultation",
    /// `Consultation with Authority`: 
    ConsultationWithAuthority, "ConsultationWithAuthority",
    /// `Contact`: 
    Contact, "Contact",
    /// `Context`: 
    Context, "Context",
    /// `Contract`: 
    Contract, "Contract",
    /// `Copy`: 
    Copy, "Copy",
    /// `Country`: 
    Country, "Country",
    /// `Create Event Recommendations`: 
    CreateEventRecommendations, "CreateEventRecommendations",
    /// `Create Personalized Recommendations`: 
    CreatePersonalizedRecommendations, "CreatePersonalizedRecommendations",
    /// `Create Product Recommendations`: 
    CreateProductRecommendations, "CreateProductRecommendations",
    /// `Credit`: 
    Credit, "Credit",
    /// `Credit Capacity`: 
    CreditCapacity, "CreditCapacity",
    /// `Credit Card Number`: 
    CreditCardNumber, "CreditCardNumber",
    /// `Credit Record`: 
    CreditRecord, "CreditRecord",
    /// `Credit Score`: 
    CreditScore, "CreditScore",
    /// `Credit Standing`: 
    CreditStanding, "CreditStanding",
    /// `Credit Worthiness`: 
    CreditWorthiness, "CreditWorthiness",
    /// `Criminal`: 
    Criminal, "Criminal",
    /// `Criminal Charge`: 
    CriminalCharge, "CriminalCharge",
    /// `Criminal Conviction`: 
    CriminalConviction, "CriminalConviction",
    /// `Criminal Pardon`: 
    CriminalPardon, "CriminalPardon",
    /// `Customer Care`: 
    CustomerCare, "CustomerCare",
    /// `DNA Code`: 
    DNACode, "DNACode",
    /// `Data Protection Impact Assessment (DPIA)`: Top class: Impact Assessment, and DPIA is sub-class
    DPIA, "DPIA",
    /// `Data Controller`: The terms 'Controller' is usually the more common form of indicating a Data Controller. In ISO/IEC the term 'PII Controller' is used.
    DataController, "DataController",
    /// `Data Processor`: 
    DataProcessor, "DataProcessor",
    /// `Data Protection Authority`: 
    DataProtectionAuthority, "DataProtectionAuthority",
    /// `Data Protection Officer`: 
    DataProtectionOfficer, "DataProtectionOfficer",
    /// `Data Source`: Source is direct point of data collection; 'origin' would indicate the original/others points of where the data originates from
    DataSource, "DataSource",
    /// `Data Sub-Processor`: sub-processor' is a commonly used term similar to 'sub-contractor' and does not have a specific legal definition
    DataSubProcessor, "DataSubProcessor",
    /// `Data Subject`: The term 'data subject' is specific to the GDPR, but is functionally equivalent to the term 'individual' and the ISO/IEC term 'PII Principle'.
    DataSubject, "DataSubject",
    /// `Data Subject Right`: Based on use of definitions, the notion of 'Data Subject Right' can be equivalent to 'Individual Right' or 'Right of a Person'
    DataSubjectRight, "DataSubjectRight",
    /// `De-Identification`: 
    DeIdentification, "DeIdentification",
    /// `Delivery of Goods`: 
    DeliveryOfGoods, "DeliveryOfGoods",
    /// `Demeanor`: 
    Demeanor, "Demeanor",
    /// `Demographic`: 
    Demographic, "Demographic",
    /// `Derive`: 
    Derive, "Derive",
    /// `Derived Personal Data`: 
    DerivedPersonalData, "DerivedPersonalData",
    /// `Design Standard`: 
    DesignStandard, "DesignStandard",
    /// `Destruct`: 
    Destruct, "Destruct",
    /// `Device Applications`: 
    DeviceApplications, "DeviceApplications",
    /// `Device Based`: 
    DeviceBased, "DeviceBased",
    /// `Device Operating System`: 
    DeviceOperatingSystem, "DeviceOperatingSystem",
    /// `Device Software`: 
    DeviceSoftware, "DeviceSoftware",
    /// `Dialect`: 
    Dialect, "Dialect",
    /// `Direct Marketing`: 
    DirectMarketing, "DirectMarketing",
    /// `Disability`: 
    Disability, "Disability",
    /// `Disciplinary Action`: 
    DisciplinaryAction, "DisciplinaryAction",
    /// `Disclose`: 
    Disclose, "Disclose",
    /// `Disclose by Transmission`: 
    DiscloseByTransmission, "DiscloseByTransmission",
    /// `Dislike`: 
    Dislike, "Dislike",
    /// `Disseminate`: 
    Disseminate, "Disseminate",
    /// `Divorce`: 
    Divorce, "Divorce",
    /// `Drug Test Result`: 
    DrugTestResult, "DrugTestResult",
    /// `Email Address`: 
    EmailAddress, "EmailAddress",
    /// `Email Content`: 
    EmailContent, "EmailContent",
    /// `Employment History`: 
    EmploymentHistory, "EmploymentHistory",
    /// `Encryption in Rest`: 
    EncryptionInRest, "EncryptionInRest",
    /// `Encryption in Transfer`: 
    EncryptionInTransfer, "EncryptionInTransfer",
    /// `Erase`: 
    Erase, "Erase",
    /// `Ethnic Origin`: 
    EthnicOrigin, "EthnicOrigin",
    /// `Ethnicity`: 
    Ethnicity, "Ethnicity",
    /// `Evaluation and Scoring`: 
    EvaluationScoring, "EvaluationScoring",
    /// `External`: 
    External, "External",
    /// `Family`: 
    Family, "Family",
    /// `Family Health History`: 
    FamilyHealthHistory, "FamilyHealthHistory",
    /// `Family Structure`: 
    FamilyStructure, "FamilyStructure",
    /// `Favorite`: 
    Favorite, "Favorite",
    /// `Favorite Color`: 
    FavoriteColor, "FavoriteColor",
    /// `Favorite Food`: 
    FavoriteFood, "FavoriteFood",
    /// `Favorite Music`: 
    FavoriteMusic, "FavoriteMusic",
    /// `Fetish`: 
    Fetish, "Fetish",
    /// `Financial`: 
    Financial, "Financial",
    /// `Financial Account`: 
    FinancialAccount, "FinancialAccount",
    /// `Financial Account Number`: 
    FinancialAccountNumber, "FinancialAccountNumber",
    /// `Fingerprint`: 
    Fingerprint, "Fingerprint",
    /// `Fraud Prevention and Detection`: 
    FraudPreventionAndDetection, "FraudPreventionAndDetection",
    /// `Friend`: 
    Friend, "Friend",
    /// `GPS Coordinate`: 
    GPSCoordinate, "GPSCoordinate",
    /// `Gender`: 
    Gender, "Gender",
    /// `General Reputation`: 
    GeneralReputation, "GeneralReputation",
    /// `Geographic`: 
    Geographic, "Geographic",
    /// `Group Membership`: 
    GroupMembership, "GroupMembership",
    /// `GuidelinesPrinciple`: 
    GuidelinesPrinciple, "GuidelinesPrinciple",
    /// `Hair Color`: 
    HairColor, "HairColor",
    /// `Health`: 
    Health, "Health",
    /// `Health History`: 
    HealthHistory, "HealthHistory",
    /// `Health Record`: 
    HealthRecord, "HealthRecord",
    /// `Height`: 
    Height, "Height",
    /// `Historical`: 
    Historical, "Historical",
    /// `House Owned`: 
    HouseOwned, "HouseOwned",
    /// `IP Address`: 
    IPAddress, "IPAddress",
    /// `Identifying`: 
    Identifying, "Identifying",
    /// `Identity Verification`: 
    IdentityVerification, "IdentityVerification",
    /// `Impact Assessment`: 
    ImpactAssessment, "ImpactAssessment",
    /// `Improve Existing Products and Services`: 
    ImproveExistingProductsAndServices, "ImproveExistingProductsAndServices",
    /// `Improve Internal CRM Processes`: 
    ImproveInternalCRMProcesses, "ImproveInternalCRMProcesses",
    /// `Income`: 
    Income, "Income",
    /// `Income Bracket`: 
    IncomeBracket, "IncomeBracket",
    /// `Increase Service Robustness`: 
    IncreaseServiceRobustness, "IncreaseServiceRobustness",
    /// `Individual Health History`: 
    IndividualHealthHistory, "IndividualHealthHistory",
    /// `Innovative Use of New Technologies`: 
    InnovativeUseOfNewTechnologies, "InnovativeUseOfNewTechnologies",
    /// `Intention`: 
    Intention, "Intention",
    /// `Interaction`: 
    Interaction, "Interaction",
    /// `Interest`: 
    Interest, "Interest",
    /// `Internal`: 
    Internal, "Internal",
    /// `Internal Resource Optimisation`: 
    InternalResourceOptimisation, "InternalResourceOptimisation",
    /// `Job`: 
    Job, "Job",
    /// `Knowledge and Beliefs`: 
    KnowledgeBelief, "KnowledgeBelief",
    /// `Language`: 
    Language, "Language",
    /// `Large Scale Processing`: 
    LargeScaleProcessing, "LargeScaleProcessing",
    /// `Legal Agreement`: 
    LegalAgreement, "LegalAgreement",
    /// `Legal Basis`: Legal basis (plural: legal bases) are defined by legislations and regulations, whose applicability is usually restricted to specific jurisdictions.
    LegalBasis, "LegalBasis",
    /// `Legal Compliance`: 
    LegalCompliance, "LegalCompliance",
    /// `Legal Entity`: 
    LegalEntity, "LegalEntity",
    /// `Life History`: 
    LifeHistory, "LifeHistory",
    /// `Like`: 
    Like, "Like",
    /// `LinkClicked`: 
    LinkClicked, "LinkClicked",
    /// `Loan Record`: 
    LoanRecord, "LoanRecord",
    /// `Location`: 
    Location, "Location",
    /// `MAC Address`: 
    MACAddress, "MACAddress",
    /// `Make Available`: 
    MakeAvailable, "MakeAvailable",
    /// `Marital Status`: 
    MaritalStatus, "MaritalStatus",
    /// `Marketing`: 
    Marketing, "Marketing",
    /// `Marriage`: 
    Marriage, "Marriage",
    /// `Matching and Combining`: 
    MatchingCombining, "MatchingCombining",
    /// `MedicalHealth`: 
    MedicalHealth, "MedicalHealth",
    /// `Mental Health`: 
    MentalHealth, "MentalHealth",
    /// `Move`: 
    Move, "Move",
    /// `Non-Disclosure Agreement (NDA)`: 
    NDA, "NDA",
    /// `Name`: 
    Name, "Name",
    /// `Non-Commercial Research`: 
    NonCommercialResearch, "NonCommercialResearch",
    /// `Obtain`: 
    Obtain, "Obtain",
    /// `Official ID`: 
    OfficialID, "OfficialID",
    /// `Offspring`: 
    Offspring, "Offspring",
    /// `Opinion`: 
    Opinion, "Opinion",
    /// `Optimisation for Consumer`: 
    OptimisationForConsumer, "OptimisationForConsumer",
    /// `Optimisation for Controller`: 
    OptimisationForController, "OptimisationForController",
    /// `Optimise User Interface`: 
    OptimiseUserInterface, "OptimiseUserInterface",
    /// `Organisational Measure`: 
    OrganisationalMeasure, "OrganisationalMeasure",
    /// `Organise`: 
    Organise, "Organise",
    /// `Ownership`: 
    Ownership, "Ownership",
    /// `Privacy Impact Assessment`: 
    PIA, "PIA",
    /// `PIN Code`: 
    PINCode, "PINCode",
    /// `Parent`: 
    Parent, "Parent",
    /// `Password`: 
    Password, "Password",
    /// `Payment`: 
    Payment, "Payment",
    /// `Payment Card`: 
    PaymentCard, "PaymentCard",
    /// `Payment Card Expiry`: 
    PaymentCardExpiry, "PaymentCardExpiry",
    /// `Payment Card Number`: 
    PaymentCardNumber, "PaymentCardNumber",
    /// `Personal Data Category`: For a formal legal definition of personal data, see GDPR Art.4-1. An informal definition consists of any data directly or indirectly associated or related to an individual. This definition is equivalent to ISO/IEC definition of Personally Identifiable Information (PII).
    PersonalDataCategory, "PersonalDataCategory",
    /// `Personal Data Handling`: 
    PersonalDataHandling, "PersonalDataHandling",
    /// `Personal Possession`: 
    PersonalPossession, "PersonalPossession",
    /// `Personalised Advertising`: 
    PersonalisedAdvertising, "PersonalisedAdvertising",
    /// `Personalised Benefits`: 
    PersonalisedBenefits, "PersonalisedBenefits",
    /// `Personality`: 
    Personality, "Personality",
    /// `Philosophical Belief`: 
    PhilosophicalBelief, "PhilosophicalBelief",
    /// `Physical Address`: 
    PhysicalAddress, "PhysicalAddress",
    /// `PhysicalCharacteristic`: 
    PhysicalCharacteristic, "PhysicalCharacteristic",
    /// `Physical Health`: 
    PhysicalHealth, "PhysicalHealth",
    /// `Physical Trait`: 
    PhysicalTrait, "PhysicalTrait",
    /// `Picture`: 
    Picture, "Picture",
    /// `Piercing`: 
    Piercing, "Piercing",
    /// `Political Affiliation`: 
    PoliticalAffiliation, "PoliticalAffiliation",
    /// `Preference`: 
    Preference, "Preference",
    /// `Prescription`: 
    Prescription, "Prescription",
    /// `Privacy by Default`: 
    PrivacyByDefault, "PrivacyByDefault",
    /// `Privacy by Design`: 
    PrivacyByDesign, "PrivacyByDesign",
    /// `Privacy Preference`: 
    PrivacyPreference, "PrivacyPreference",
    /// `Processing`: 
    Processing, "Processing",
    /// `Proclivitie`: 
    Proclivitie, "Proclivitie",
    /// `Professional`: 
    Professional, "Professional",
    /// `Professional Certification`: 
    ProfessionalCertification, "ProfessionalCertification",
    /// `Professional Evaluation`: 
    ProfessionalEvaluation, "ProfessionalEvaluation",
    /// `Professional Interview`: 
    ProfessionalInterview, "ProfessionalInterview",
    /// `Profiling`: 
    Profiling, "Profiling",
    /// `Pseudo-Anonymise`: 
    PseudoAnonymise, "PseudoAnonymise",
    /// `Pseudo-Anonymization`: 
    PseudoAnonymization, "PseudoAnonymization",
    /// `Pseudonymisation and Encryption`: 
    PseudonymisationEncryption, "PseudonymisationEncryption",
    /// `Public Life`: 
    PublicLife, "PublicLife",
    /// `Purchase`: 
    Purchase, "Purchase",
    /// `Purchases and Spending Habit`: 
    PurchasesAndSpendingHabit, "PurchasesAndSpendingHabit",
    /// `Purpose`: 
    Purpose, "Purpose",
    /// `Race`: 
    Race, "Race",
    /// `Recipient`: A recipient of personal data can be used to indicate any entity that receives personal data. This can be a Third Party, Processor (GDPR), or even a Controller.
    Recipient, "Recipient",
    /// `Record`: 
    Record, "Record",
    /// `Reference`: 
    Reference, "Reference",
    /// `Registration and Authentication`: 
    RegistrationAuthentication, "RegistrationAuthentication",
    /// `Regularity of Re-certification`: 
    RegularityOfRecertification, "RegularityOfRecertification",
    /// `Relationship`: 
    Relationship, "Relationship",
    /// `Religion`: 
    Religion, "Religion",
    /// `Religious Belief`: 
    ReligiousBelief, "ReligiousBelief",
    /// `Remove`: 
    Remove, "Remove",
    /// `Representative`: 
    Representative, "Representative",
    /// `RequestedServiceProvision`: 
    RequestedServiceProvision, "RequestedServiceProvision",
    /// `Research and Development`: 
    ResearchAndDevelopment, "ResearchAndDevelopment",
    /// `Restrict`: 
    Restrict, "Restrict",
    /// `Retina`: 
    Retina, "Retina",
    /// `Retrieve`: 
    Retrieve, "Retrieve",
    /// `Right`: A 'right' is a legal, social, or ethical principle of freedom or entitlement which dictate the norms regarding what is allowed or owed.. Rights as a concept encompass a broad area of norms and entities, and are not specific to Individuals or Data Protection / Privacy. For individual specific rights, see dpv:DataSubjectRight
    Right, "Right",
    /// `Risk`: Risks can be associated with one or more different concepts such as purpose, processing, personal data, technical or organisational measure.
    Risk, "Risk",
    /// `Risk Management Procedure`: Data Protection Impact Assessments as per GDPR art 35, other Privacy Impact Assessments, threat severity assessment https://www.cnil.fr/en/privacy-impact-assessment-pia
    RiskManagementProcedure, "RiskManagementProcedure",
    /// `Risk Mitigation Measure`: 
    RiskMitigationMeasure, "RiskMitigationMeasure",
    /// `Room Number`: 
    RoomNumber, "RoomNumber",
    /// `Salary`: 
    Salary, "Salary",
    /// `Sale`: 
    Sale, "Sale",
    /// `School`: 
    School, "School",
    /// `Seal`: 
    Seal, "Seal",
    /// `Secret Text`: 
    SecretText, "SecretText",
    /// `Sector`: There are various sector codes used commonly to indicate the domain of an organisation or business. Examples include NACE (EU), ISIC (UN), SIC and NAICS (USA).
    Sector, "Sector",
    /// `Security`: 
    Security, "Security",
    /// `Sell Data to Third Parties`: 
    SellDataToThirdParties, "SellDataToThirdParties",
    /// `Sell Insights from Data`: 
    SellInsightsFromData, "SellInsightsFromData",
    /// `Sell Products to Data Subject`: 
    SellProductsToDataSubject, "SellProductsToDataSubject",
    /// `Sell Targetted Advertisements`: 
    SellTargettedAdvertisements, "SellTargettedAdvertisements",
    /// `Service Consumption Behavior`: 
    ServiceConsumptionBehavior, "ServiceConsumptionBehavior",
    /// `Service Optimization`: 
    ServiceOptimization, "ServiceOptimization",
    /// `Service Personalization`: 
    ServicePersonalization, "ServicePersonalization",
    /// `Service Provision`: 
    ServiceProvision, "ServiceProvision",
    /// `Sexual`: 
    Sexual, "Sexual",
    /// `Sexual History`: 
    SexualHistory, "SexualHistory",
    /// `Sexual Preference`: 
    SexualPreference, "SexualPreference",
    /// `Share`: 
    Share, "Share",
    /// `Sibling`: 
    Sibling, "Sibling",
    /// `Single Sign On`: 
    SingleSignOn, "SingleSignOn",
    /// `Skin Tone`: 
    SkinTone, "SkinTone",
    /// `Social`: 
    Social, "Social",
    /// `Social Media Communication`: 
    SocialMediaCommunication, "SocialMediaCommunication",
    /// `Social Media`: 
    SocialMediaMarketing, "SocialMediaMarketing",
    /// `Social Network`: 
    SocialNetwork, "SocialNetwork",
    /// `Social Status`: 
    SocialStatus, "SocialStatus",
    /// `Special Category Personal Data`: trade union membership, which is explicitly included in the taxative listing in GDPR Art. 9 (1), is not covered yet.
    SpecialCategoryPersonalData, "SpecialCategoryPersonalData",
    /// `Staff Training`: 
    StaffTraining, "StaffTraining",
    /// `Storage Deletion`: 
    StorageDeletion, "StorageDeletion",
    /// `Storage Duration`: 
    StorageDuration, "StorageDuration",
    /// `Storage Location`: 
    StorageLocation, "StorageLocation",
    /// `Storage Restoration`: 
    StorageRestoration, "StorageRestoration",
    /// `Storage Restriction`: 
    StorageRestriction, "StorageRestriction",
    /// `Store`: 
    Store, "Store",
    /// `Structure`: 
    Structure, "Structure",
    /// `Systematic Monitoring`: 
    SystematicMonitoring, "SystematicMonitoring",
    /// `TV Viewing Behavior`: 
    TVViewingBehavior, "TVViewingBehavior",
    /// `Tattoo`: 
    Tattoo, "Tattoo",
    /// `Tax`: 
    Tax, "Tax",
    /// `Technical Measure`: 
    TechnicalMeasure, "TechnicalMeasure",
    /// `Technical and Organisational Measure`: 
    TechnicalOrganisationalMeasure, "TechnicalOrganisationalMeasure",
    /// `Telephone Number`: 
    TelephoneNumber, "TelephoneNumber",
    /// `Third Party`: 
    ThirdParty, "ThirdParty",
    /// `Thought`: 
    Thought, "Thought",
    /// `Tracking`: 
    Tracking, "Tracking",
    /// `Transaction`: 
    Transaction, "Transaction",
    /// `Transactional`: 
    Transactional, "Transactional",
    /// `Transfer`: 
    Transfer, "Transfer",
    /// `Transform`: 
    Transform, "Transform",
    /// `Transmit`: 
    Transmit, "Transmit",
    /// `UID`: 
    UID, "UID",
    /// `Analytics`: 
    UsageAnalytics, "UsageAnalytics",
    /// `Use`: 
    Use, "Use",
    /// `User Interface Personalisation`: 
    UserInterfacePersonalisation, "UserInterfacePersonalisation",
    /// `Username`: 
    Username, "Username",
    /// `Voice Communication Recording`: 
    VoiceCommunicationRecording, "VoiceCommunicationRecording",
    /// `Voice Mail`: 
    VoiceMail, "VoiceMail",
    /// `Vulnerable Data Subject`: 
    VulnerableDataSubject, "VulnerableDataSubject",
    /// `Weight`: 
    Weight, "Weight",
    /// `Work History`: 
    WorkHistory, "WorkHistory",
    /// `expiry`: 
    expiry, "expiry",
    /// `has address`: 
    hasAddress, "hasAddress",
    /// `has algorithmic logic`: 
    hasAlgorithmicLogic, "hasAlgorithmicLogic",
    /// `has consent notice`: The actual notice that the Data Subject received to consent to, either a text or link to a document, which should be usable to decide whether the form or consent was compliant to legislation, e.g. documenting how the user has been informed about rights and implications (such as, right to data portability,right to recitffy, right to erasure, right to restrict processing, right to object, rights regarding automated decision making or profiling, processors, third parties, sub-processors, outside-EEA transfers, automated decision-making, or other necessary details of the privacy-policy). Can be TextOrDocumentOrURI.
    hasConsentNotice, "hasConsentNotice",
    /// `has consequences`: 
    hasConsequences, "hasConsequences",
    /// `has contact`: 
    hasContact, "hasContact",
    /// `has context`: 
    hasContext, "hasContext",
    /// `has data controller`: 
    hasDataController, "hasDataController",
    /// `has data source`: 
    hasDataSource, "hasDataSource",
    /// `has data subject`: 
    hasDataSubject, "hasDataSubject",
    /// `has duration`: 
    hasDuration, "hasDuration",
    /// `has expiry`: 
    hasExpiry, "hasExpiry",
    /// `has expiry condition`: Can be TextOrDocumentOrURI
    hasExpiryCondition, "hasExpiryCondition",
    /// `has expiry time`: 
    hasExpiryTime, "hasExpiryTime",
    /// `has human involvement`: Human involvement is also relevant to 'human in the loop'
    hasHumanInvolvement, "hasHumanInvolvement",
    /// `has identifier`: 
    hasIdentifier, "hasIdentifier",
    /// `has legal basis`: 
    hasLegalBasis, "hasLegalBasis",
    /// `has location`: 
    hasLocation, "hasLocation",
    /// `has name`: 
    hasName, "hasName",
    /// `has personal data category`: 
    hasPersonalDataCategory, "hasPersonalDataCategory",
    /// `has processing`: 
    hasProcessing, "hasProcessing",
    /// `has provision by`: Normally this would be the dataSubject, but in some exceptional cases, the consent might be given on behalf by someone else, e.g. parents of minors.
    hasProvisionBy, "hasProvisionBy",
    /// `has provision by justification`: This field can be used to proivde a justification why the provision was provided by another DataSubject or legal entity,  e.g. declariing the relationship (parent, guardian), in combination with the field provisionBy
    hasProvisionByJustification, "hasProvisionByJustification",
    /// `has provision method`: Can be used to record information of how consent was provided e.g. by a click to a form, in writing, etc., by logging into a system and confirm per email, or with some additional authentication, etc.
    hasProvisionMethod, "hasProvisionMethod",
    /// `has provision time`: 
    hasProvisionTime, "hasProvisionTime",
    /// `has purpose`: 
    hasPurpose, "hasPurpose",
    /// `has recipient`: 
    hasRecipient, "hasRecipient",
    /// `has representative`: 
    hasRepresentative, "hasRepresentative",
    /// `has right`: 
    hasRight, "hasRight",
    /// `has risk`: 
    hasRisk, "hasRisk",
    /// `has sector`: 
    hasSector, "hasSector",
    /// `has storage`: 
    hasStorage, "hasStorage",
    /// `has technical and organisational measure`: 
    hasTechnicalOrganisationalMeasure, "hasTechnicalOrganisationalMeasure",
    /// `has withdrawal by`: Normally this would be the dataSubject, but in some exceptional cases, the consent might be withdraawn on behalf by someone else, e.g. parents of minors.
    hasWithdrawalBy, "hasWithdrawalBy",
    /// `has withdrawal by justification`: This field can be used to proivde a justification why the weithdrawal was done by another DataSubject or legal entity, e.g. declariing the relationship (parent, guardian), in combination with the field withdrawalBy
    hasWithdrawalByJustification, "hasWithdrawalByJustification",
    /// `has withdrawal method`: Can be used to record information of how to withdraw consent, e.g. by a click to a form, in writing, etc., by logging into a system and confirm per email, or with some additional authentication, etc.
    hasWithdrawalMethod, "hasWithdrawalMethod",
    /// `has withdrawal time`: 
    hasWithdrawalTime, "hasWithdrawalTime",
    /// `is explicit`: The conditions for what is considered 'explicit consent' differ by norms and laws.
    isExplicit, "isExplicit",
    /// `measure implemented by`: 
    measureImplementedBy, "measureImplementedBy",
    /// `mitigates risk`: 
    mitigatesRisk, "mitigatesRisk"
);
